//@line 4 "/builds/slave/tb-rel-c-beta-lx_rpk_5-0000000/l10n/hr/calendar/lightning-l10n.js"

//@line 6 "/builds/slave/tb-rel-c-beta-lx_rpk_5-0000000/l10n/hr/calendar/lightning-l10n.js"

//@line 9 "/builds/slave/tb-rel-c-beta-lx_rpk_5-0000000/l10n/hr/calendar/lightning-l10n.js"
pref("calendar.week.start", 1);

//@line 12 "/builds/slave/tb-rel-c-beta-lx_rpk_5-0000000/l10n/hr/calendar/lightning-l10n.js"
pref("calendar.week.d0sundaysoff", true);
pref("calendar.week.d1mondaysoff", false);
pref("calendar.week.d2tuesdaysoff", false);
pref("calendar.week.d3wednesdaysoff", false);
pref("calendar.week.d4thursdaysoff", false);
pref("calendar.week.d5fridaysoff", false);
pref("calendar.week.d6saturdaysoff", true);

pref("general.useragent.locale", "hr");

//@line 23 "/builds/slave/tb-rel-c-beta-lx_rpk_5-0000000/l10n/hr/calendar/lightning-l10n.js"
pref("calendar.categories.names", "Godišnjica,Rođendan,Posao,Pozivi,Klijenti,Konkurencija,Kupac,Omiljeno,Nastaviti,Pokloni,Praznici,Ideje,Problemi,Sastanak,Razno,Osobno,Projekti,Javni praznik,Status,Dobavljači,Putovanje,Odmor");
